/**
 * Copyright 2007 Jens Kapitza
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ajaxtags.server;

import org.ajaxtags.xml.AjaxXmlBuilder;

/**
 * the Observer interface wich is used to update callback requests
 * 
 * @author Jens Kapitza
 * @version $Revision: 1.3 $ $Date: 2007/08/05 13:29:39 $ $Author: jenskapitza $
 * 
 */
public interface ICallback {

	/**
	 * update al observers and send them this xml file
	 * 
	 * setzt den count wieder auf 0
	 * 
	 * @param xml
	 *            the xml data to send
	 * @throws NullPointerException
	 *             if xml is null
	 */
	public void quickUpdate(AjaxXmlBuilder xml);

	/**
	 * add an Observer
	 * 
	 * @param o
	 */
	public void add(ICallbackClient o);

	/**
	 * add an Observer and wait
	 * 
	 * @param o
	 * @throws InterruptedException
	 */
	public void addAndWait(ICallbackClient o) throws InterruptedException;

	/**
	 * thread count
	 * 
	 * @return the number of observers
	 * 
	 */
	public int countObservers();
}
