/**
 * Copyright 2005 Darren L. Spurgeon
 * Copyright 2007 Jens Kapitza
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ajaxtags.servlets;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


/**
 * An abstract class from which each example servlet extends. This class wraps
 * the XML creation (delegated to the child servlet class) and submission back
 * through the HTTP response.
 * 
 * @author Darren L. Spurgeon
 * @author Jens Kapitza
 * @version $Revision: 1.8 $ $Date: 2007/07/22 16:29:16 $ $Author: jenskapitza $
 */
public abstract class BaseAjaxServlet extends HttpServlet implements BaseAjaxXmlAction {

	/**
	 * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse)
	 */
	@Override
	protected void doGet(HttpServletRequest request, HttpServletResponse response)
			throws ServletException, IOException {

		try {
			String xml = null;
			xml = AjaxActionHelper.invoke(this, request, response);
			PrintWriter pw = response.getWriter();
			pw.write(xml);
			pw.close();

		} catch (Exception ex) {
			// Send back a 500 error code.
			response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR,
					"Can not create response");
			return;
		}
	}

	/**
	 * @see javax.servlet.http.HttpServlet#doPost(javax.servlet.http.HttpServletRequest,
	 *      javax.servlet.http.HttpServletResponse)
	 */
	@Override
	protected void doPost(HttpServletRequest request, HttpServletResponse response)
			throws ServletException, IOException {
		doGet(request, response);
	}

	/**
	 * Each child class should override this method to generate the specific XML
	 * content necessary for each AJAX action.
	 * 
	 * @param request
	 *            the {@javax.servlet.http.HttpServletRequest} object
	 * @param response
	 *            the {@javax.servlet.http.HttpServletResponse} object
	 * @return a {@java.lang.String} representation of the XML response/content
	 */
	public abstract String getXmlContent(HttpServletRequest request,
			HttpServletResponse response) throws Exception;
}
