/**
 * Copyright 2007 Jens Kapitza
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ajaxtags.tags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

/**
 * Realize a Server Update
 * 
 * @author Jens Kapitza
 * 
 * @version $Revision: 1.1 $ $Date: 2007/06/23 18:36:51 $ $Author: jenskapitza $
 */
public class AjaxServerCallback extends TagSupport {
	private String parser;
	private String url;
	private String errorFunction;
	private String postFunction;
	private String preFunction;
	private boolean plainText;

	@Override
	public int doStartTag() throws JspException {
		// kein body
		return SKIP_BODY;
	}

	@Override
	public int doEndTag() throws JspException {
		// nun das JS erzeugen
		JspWriter writer = pageContext.getOut();
		// vertige JS function aufrufen!
		OptionsBuilder options = new OptionsBuilder();

		options.add("plainText", String.valueOf(this.plainText), false);

		if (this.preFunction != null)
			options.add("preFunction", this.preFunction, false);
		if (this.postFunction != null)
			options.add("postFunction", this.postFunction, false);
		if (this.errorFunction != null)
			options.add("errorFunction", this.errorFunction, false);
		if (this.parser != null)
			options.add("parser", this.parser, false);

		StringBuffer script = new StringBuffer();
		script.append("<script type=\"text/javascript\">\n");
		script.append("new AjaxJspTag.Callback('" + this.url + "',{"
				+ options.toString() + "});\n");
		script.append("</script>\n");
		try {
			writer.println(script);
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}

		return EVAL_PAGE;
	}

	public String getParser() {
		return parser;
	}

	public void setParser(String parser) {
		this.parser = parser;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getErrorFunction() {
		return errorFunction;
	}

	public void setErrorFunction(String errorFunction) {
		this.errorFunction = errorFunction;
	}

	public String getPostFunction() {
		return postFunction;
	}

	public void setPostFunction(String postFunction) {
		this.postFunction = postFunction;
	}

	public String getPreFunction() {
		return preFunction;
	}

	public void setPreFunction(String preFunction) {
		this.preFunction = preFunction;
	}
 
	public boolean isPlainText() {
		return plainText;
	}

	public void setPlainText(boolean plainText) {
		this.plainText = plainText;
	}
}
