/**
 * Copyright 2005 Darren L. Spurgeon
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ajaxtags.tags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

import org.apache.commons.lang.StringUtils;
import org.apache.taglibs.standard.lang.support.ExpressionEvaluatorManager;

/**
 * Tag handler for AJAX tabbed panel.
 * 
 * @author Darren Spurgeon
 * @version $Revision: 1.2 $ $Date: 2007/06/20 20:55:56 $ $Author: jenskapitza $
 */
public class AjaxTabPanelTag extends TagSupport {

	private String var;

	private String attachTo;

	private String panelStyleId;

	private String contentStyleId;

	private String panelStyleClass;

	private String contentStyleClass;

	private String currentStyleClass;

	private String defaultTabBaseUrl;

	private String defaultTabParameters = "";

	private String preFunction;

	private String postFunction;

	private String errorFunction;

	private String parser;

	public String getContentStyleId() {
		return contentStyleId;
	}

	public void setContentStyleId(String contentStyleId) {
		this.contentStyleId = contentStyleId;
	}

	public String getDefaultTabParameters() {
		return defaultTabParameters;
	}

	public void setDefaultTabParameters(String defaultTabParameters) {
		this.defaultTabParameters = defaultTabParameters;
	}

	public String getDefaultTabBaseUrl() {
		return defaultTabBaseUrl;
	}

	public void setDefaultTabBaseUrl(String defaultTab) {
		this.defaultTabBaseUrl = defaultTab;
	}

	public String getErrorFunction() {
		return errorFunction;
	}

	public void setErrorFunction(String errorFunction) {
		this.errorFunction = errorFunction;
	}

	public String getPanelStyleId() {
		return panelStyleId;
	}

	public void setPanelStyleId(String panelStyleId) {
		this.panelStyleId = panelStyleId;
	}

	public String getParser() {
		return parser;
	}

	public void setParser(String parser) {
		this.parser = parser;
	}

	public String getPreFunction() {
		return preFunction;
	}

	public void setPreFunction(String preFunction) {
		this.preFunction = preFunction;
	}

	public String getPostFunction() {
		return postFunction;
	}

	public void setPostFunction(String postFunction) {
		this.postFunction = postFunction;
	}

	public String getVar() {
		return var;
	}

	public void setVar(String var) {
		this.var = var;
	}

	public String getAttachTo() {
		return attachTo;
	}

	public void setAttachTo(String attachTo) {
		this.attachTo = attachTo;
	}

	public String getContentStyleClass() {
		return contentStyleClass;
	}

	public void setContentStyleClass(String contentStyleClass) {
		this.contentStyleClass = contentStyleClass;
	}

	public String getCurrentStyleClass() {
		return currentStyleClass;
	}

	public void setCurrentStyleClass(String currentStyleClass) {
		this.currentStyleClass = currentStyleClass;
	}

	public String getPanelStyleClass() {
		return panelStyleClass;
	}

	public void setPanelStyleClass(String panelStyleClass) {
		this.panelStyleClass = panelStyleClass;
	}

	@Override
	public int doStartTag() throws JspException {
		// Required Properties
		this.panelStyleId = (String) ExpressionEvaluatorManager.evaluate(
				"panelStyleId", this.panelStyleId, String.class, this,
				super.pageContext);
		this.contentStyleId = (String) ExpressionEvaluatorManager.evaluate(
				"contentStyleId", this.contentStyleId, String.class, this,
				super.pageContext);
		this.currentStyleClass = (String) ExpressionEvaluatorManager.evaluate(
				"currentStyleClass", this.currentStyleClass, String.class,
				this, super.pageContext);

		// Optional Properties
		if (this.var != null) {
			this.var = (String) ExpressionEvaluatorManager.evaluate("var",
					this.var, String.class, this, super.pageContext);
		}
		if (this.attachTo != null) {
			this.attachTo = (String) ExpressionEvaluatorManager.evaluate(
					"attachTo", this.attachTo, String.class, this,
					super.pageContext);
		}
		if (this.preFunction != null) {
			this.preFunction = (String) ExpressionEvaluatorManager.evaluate(
					"preFunction", this.preFunction, String.class, this,
					super.pageContext);
		}
		if (this.postFunction != null) {
			this.postFunction = (String) ExpressionEvaluatorManager.evaluate(
					"postFunction", this.postFunction, String.class, this,
					super.pageContext);
		}
		if (this.errorFunction != null) {
			this.errorFunction = (String) ExpressionEvaluatorManager.evaluate(
					"errorFunction", this.errorFunction, String.class, this,
					super.pageContext);
		}

		StringBuffer script = new StringBuffer();
		script.append("<div id=\"");
		script.append(this.panelStyleId);
		script.append("\" class=\"");
		script.append(this.panelStyleClass);
		script.append("\">\n<ul>");
		JspWriter writer = pageContext.getOut();
		try {
			writer.println(script);
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}
		return EVAL_BODY_INCLUDE;
	}

	@Override
	public int doEndTag() throws JspException {
		OptionsBuilder options = new OptionsBuilder();
		options.add("source", "elem", false);
		options.add("target", this.contentStyleId, true);
		options.add("panelId", this.panelStyleId, true);
		options.add("currentStyleClass", "currentClass", false);
		options.add("parameters", "params", false);
		if (this.preFunction != null)
			options.add("preFunction", this.preFunction, false);
		if (this.postFunction != null)
			options.add("postFunction", this.postFunction, false);
		if (this.errorFunction != null)
			options.add("errorFunction", this.errorFunction, false);
		if (this.parser != null)
			options.add("parser", this.parser, false);

		StringBuffer script = new StringBuffer();
		script.append("</ul>\n</div>\n<div id=\"");
		script.append(this.contentStyleId);
		script.append("\" class=\"");
		script.append(this.contentStyleClass);
		script.append("\"></div>\n");
		script.append("<script type=\"text/javascript\">\n");
		script.append("window.executeAjaxTab_");
		script.append(panelStyleId);
		script.append(" = function(elem, currentClass, url, params) {\n");

		if (StringUtils.isNotEmpty(this.attachTo)) {
			script.append(this.attachTo).append(".");
			if (StringUtils.isNotEmpty(this.var)) {
				script.append(this.var);
			} else {
				script.append("aj_").append(this.panelStyleId);
			}
		} else if (StringUtils.isNotEmpty(this.var)) {
			script.append("var ").append(this.var);
		} else {
			script.append("var aj_").append(this.panelStyleId);
		}

		script.append(" = new AjaxJspTag.TabPanel(url, {\n").append(
				options.toString()).append("});\n").append("}\n\n").append(
				"addOnLoadEvent(function() {window.executeAjaxTab_").append(
				panelStyleId).append("(null, '").append(this.currentStyleClass)
				.append("', '").append(this.getDefaultTabBaseUrl()).append(
						"', '").append(this.getDefaultTabParameters()).append(
						"');});\n").append("</script>\n\n");
		JspWriter writer = pageContext.getOut();
		try {
			writer.println(script);
		} catch (IOException e) {
			throw new JspException(e.getMessage());
		}
		return EVAL_PAGE;
	}

	@Override
	public void release() {
		this.var = null;
		this.attachTo = null;
		this.panelStyleId = null;
		this.contentStyleId = null;
		this.panelStyleClass = null;
		this.contentStyleClass = null;
		this.currentStyleClass = null;
		this.defaultTabBaseUrl = null;
		this.defaultTabParameters = null;
		this.preFunction = null;
		this.postFunction = null;
		this.errorFunction = null;
		this.parser = null;
		super.release();
	}

}
